@@ -12,7 +12,11 @@ my $t = new Image::Thumbnail(
 	inputpath=>'t/test.jpg',
 	outputpath=>'t/test_t.jpg',
 );
-print "ok 2\n";
+if ($t->{x}){
+	print "ok 2\n";
+} else {
+	print "not ok 2\n";
+}
 print $t->{x}==55? "ok 3\n" : "not ok 3\n";
 print $t->{y}==49? "ok 4\n" : "not ok 4\n";
 unlink("t/test_t.jpg") or print "not ok 5\n";
